Augment data with fitted classes and regime probabilities (broom method)
Source:R/broom.R
augment.iord.RdAugment data with fitted classes and regime probabilities (broom method)
Value
The estimation data with .fitted (the modal category), .prob_<level>
columns, and for inflated models .regime (fitted \(P(s = 1)\)).
See also
predict.iord() for the full set of prediction types.
Other broom methods:
glance.iord(),
tidy.iord()